@@ -116,17 +116,27 @@ class Connection(object):
         in settings.LDAP_AUTH_USER_LOOKUP_FIELDS.
         """
         # Search the LDAP database.
-        if self._connection.search(
+        if self.has_user(**kwargs):
+            return self._get_or_create_user(self._connection.response[0])
+        logger.warning("LDAP user lookup failed")
+        return None
+
+    def has_user(self, **kwargs):
+        """
+        Returns True if the user with the given identifier exists.
+
+        The user identifier should be keyword arguments matching the fields
+        in settings.LDAP_AUTH_USER_LOOKUP_FIELDS.
+        """
+        # Search the LDAP database.
+        return self._connection.search(
             search_base=settings.LDAP_AUTH_SEARCH_BASE,
             search_filter=format_search_filter(kwargs),
             search_scope=ldap3.SUBTREE,
             attributes=ldap3.ALL_ATTRIBUTES,
             get_operational_attributes=True,
             size_limit=1,
-        ):
-            return self._get_or_create_user(self._connection.response[0])
-        logger.warning("LDAP user lookup failed")
-        return None
+        )
 
 
 @contextmanager
@@ -192,6 +202,9 @@ def connection(**kwargs):
         return
     # Configure.
     try:
+        # Start TLS, if requested.
+        if settings.LDAP_AUTH_USE_TLS:
+            c.start_tls(read_server_info=False)
         # Perform initial authentication bind.
         c.bind(read_server_info=True)
         # If the settings specify an alternative username and password for querying, rebind as that.
